# Parsec Cloud (https://parsec.cloud) Copyright (c) AGPLv3 2019 Scille SAS
# Copyright 2020 BitLogiK for guardata (https://guardata.app) - AGPLv3

import click

from guardata.utils import trio_run
from guardata.cli_utils import spinner, cli_exception_handler
from guardata.api.protocol import UserID
from guardata.client.types import BackendOrganizationClaimUserAddr
from guardata.client.invite_claim import generate_invitation_token, invite_and_create_user
from guardata.client.cli.utils import client_config_and_device_options


async def _invite_user(config, device, invited_user_id, admin):
    action_addr = BackendOrganizationClaimUserAddr.build(
        organization_addr=device.organization_addr, user_id=invited_user_id
    )
    token = generate_invitation_token()

    action_addr_display = click.style(action_addr.to_url(), fg="yellow")
    token_display = click.style(token, fg="yellow")
    click.echo(f"url: {action_addr_display}")
    click.echo(f"token: {token_display}")

    async with spinner("Waiting for invitation reply"):
        invite_device_id = await invite_and_create_user(
            device=device,
            user_id=invited_user_id,
            token=token,
            is_admin=admin,
            keepalive=config.backend_connection_keepalive,
        )

    display_device = click.style(invite_device_id, fg="yellow")
    click.echo(f"Device {display_device} has been created")


@click.command()
@client_config_and_device_options
@click.option("--admin", is_flag=True)
@click.argument("invited_user_id", type=UserID, required=True)
def invite_user(config, device, admin, invited_user_id, **kwargs):
    with cli_exception_handler(config.debug):
        trio_run(_invite_user, config, device, invited_user_id, admin)
